You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [6/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/inc...

Modified: openoffice/trunk/main/shell/source/backends/wininetbe/wininetbackend.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/backends/wininetbe/wininetbackend.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/backends/wininetbe/wininetbackend.cxx (original)
+++ openoffice/trunk/main/shell/source/backends/wininetbe/wininetbackend.cxx Tue Apr 29 19:25:03 2014
@@ -122,7 +122,7 @@ WinInetBackend::WinInetBackend()
         {
             LPINTERNET_PROXY_INFO lpi = NULL;
 
-            // query for the neccessary space
+            // query for the necessary space
             DWORD dwLength = 0;
             BOOL bRet = lpfnInternetQueryOption(
                 NULL,

Modified: openoffice/trunk/main/shell/source/tools/lngconvex/lngconvex.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/tools/lngconvex/lngconvex.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/tools/lngconvex/lngconvex.cxx (original)
+++ openoffice/trunk/main/shell/source/tools/lngconvex/lngconvex.cxx Tue Apr 29 19:25:03 2014
@@ -469,7 +469,7 @@ void start_language_section(
     char buff[10];
     int primLangID = PRIMARYLANGID(ltype);
     int subLangID = SUBLANGID(ltype);
-    // Our resources are normaly not sub language dependant.
+    // Our resources are normaly not sub language dependent.
     // Esp. for spanish we don't want to distinguish between trad.
     // and internatinal sorting ( which leads to two different sub languages )
     // Setting the sub language to neutral allows us to use one

Modified: openoffice/trunk/main/shell/source/win32/SysShExec.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/SysShExec.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/SysShExec.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/SysShExec.cxx Tue Apr 29 19:25:03 2014
@@ -297,7 +297,7 @@ void SAL_CALL CSysShExec::execute( const
     /*  #i4789#; jump mark detection on system paths
         if the given command is a system path (not http or
         other uri schemes) and seems to have a jump mark
-        and names no existing file (remeber the jump mark
+        and names no existing file (remember the jump mark
         sign '#' is a valid file name character we remove 
         the jump mark, else ShellExecuteEx fails */    
     OUString preprocessed_command(aCommand);    

Modified: openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx Tue Apr 29 19:25:03 2014
@@ -117,7 +117,7 @@ ULONG STDMETHODCALLTYPE CInfoTip::Releas
 
 //********************helper functions for GetInfoTip functions**********************
 
-/** get file type infomation from registry.
+/** get file type information from registry.
 */
 std::wstring getFileTypeInfo(const std::string& file_extension)
 {
@@ -194,7 +194,7 @@ std::wstring formatSizeOfFile( DWORD dwS
 }
 
 
-/** get file size infomation.
+/** get file size information.
 */
 std::wstring getFileSizeInfo(char* FileName)
 {
@@ -283,7 +283,7 @@ HRESULT STDMETHODCALLTYPE CInfoTip::GetI
         //return E_FAIL;
     }
 
-    //display file size, no matter other infomation is loaded successfully or not.
+    //display file size, no matter other information is loaded successfully or not.
     std::wstring tmpSizeStr = getFileSizeInfo( m_szFileName );
     if ( tmpSizeStr != EMPTY_STRING )
     {

Modified: openoffice/trunk/main/shell/source/win32/shlxthandler/util/utilities.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/shlxthandler/util/utilities.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/shlxthandler/util/utilities.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/shlxthandler/util/utilities.cxx Tue Apr 29 19:25:03 2014
@@ -145,7 +145,7 @@ bool HasOnlySpaces(const std::wstring& S
 }
 
 //---------------------------------
-/** helper function to convert windows pathes to short form.
+/** helper function to convert windows paths to short form.
     @returns
         shortend path.
 */

Modified: openoffice/trunk/main/shell/source/win32/workbench/TestSmplMail.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/workbench/TestSmplMail.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/workbench/TestSmplMail.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/workbench/TestSmplMail.cxx Tue Apr 29 19:25:03 2014
@@ -88,7 +88,7 @@ int SAL_CALL main(int , char*, char* )
 	OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
 	Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( g_xFactory.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
@@ -167,7 +167,7 @@ int SAL_CALL main(int , char*, char* )
 	// Cast factory to XComponent
 	Reference< XComponent > xComponent( g_xFactory, UNO_QUERY );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( xComponent.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Error shuting down");

Modified: openoffice/trunk/main/shell/source/win32/workbench/TestSysShExec.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/workbench/TestSysShExec.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/workbench/TestSysShExec.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/workbench/TestSysShExec.cxx Tue Apr 29 19:25:03 2014
@@ -97,7 +97,7 @@ int SAL_CALL main(int nArgc, char* Argv[
 	OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
 	Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( g_xFactory.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
@@ -143,7 +143,7 @@ int SAL_CALL main(int nArgc, char* Argv[
 	// Cast factory to XComponent
 	Reference< XComponent > xComponent( g_xFactory, UNO_QUERY );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( xComponent.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Error shuting down");

Modified: openoffice/trunk/main/slideshow/source/engine/OGLTrans/OGLTrans_TransitionImpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/OGLTrans/OGLTrans_TransitionImpl.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/OGLTrans/OGLTrans_TransitionImpl.hxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/OGLTrans/OGLTrans_TransitionImpl.hxx Tue Apr 29 19:25:03 2014
@@ -282,7 +282,7 @@ private:
 	vector<basegfx::B2DVector> TexCoords;
 };
 
-/** This class is to be derived to make any operation (tranform) you may need in order to construct your transitions
+/** This class is to be derived to make any operation (transform) you may need in order to construct your transitions
 */
 class Operation
 {

Modified: openoffice/trunk/main/slideshow/source/engine/animatedsprite.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/animatedsprite.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/animatedsprite.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/animatedsprite.cxx Tue Apr 29 19:25:03 2014
@@ -101,7 +101,7 @@ namespace slideshow
         {
             // Enlarge or reduce the sprite size, if necessary.  This
             // method employs a strategy similar to container, when
-            // allocating memory: size is doubled or halved everytime
+            // allocating memory: size is doubled or halved every time
             // the limit is reached. This makes for amortized constant
             // time in runtime complexity. Note that we take exact
             // powers of two here, since several HW-accelerated canvas

Modified: openoffice/trunk/main/slideshow/source/engine/animationnodes/basenode.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/animationnodes/basenode.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/animationnodes/basenode.hxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/animationnodes/basenode.hxx Tue Apr 29 19:25:03 2014
@@ -148,7 +148,7 @@ protected:
     
 private:
     // all state affecting methods have "_st" counterparts being called at
-    // derived classes when in state transistion: no-ops here at BaseNode...
+    // derived classes when in state transition: no-ops here at BaseNode...
     virtual bool init_st();
     virtual bool resolve_st();
     virtual void activate_st();

Modified: openoffice/trunk/main/slideshow/source/engine/shapes/drawshapesubsetting.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/shapes/drawshapesubsetting.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/shapes/drawshapesubsetting.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/shapes/drawshapesubsetting.cxx Tue Apr 29 19:25:03 2014
@@ -660,7 +660,7 @@ namespace slideshow
                 };
             }
 
-            /// Counts number of class occurences
+            /// Counts number of class occurrences
             class CountClassFunctor
             {
             public:
@@ -678,7 +678,7 @@ namespace slideshow
                     if( eCurrElemClassification == meClass )
                         ++mnCurrCount;
 
-                    return true; // never stop, count all occurences
+                    return true; // never stop, count all occurrences
                 }
 
                 sal_Int32 getCount() const
@@ -703,7 +703,7 @@ namespace slideshow
             // actions
             CountClassFunctor aFunctor( eRequestedClass );
 
-            // count all occurences in the given range
+            // count all occurrences in the given range
             iterateActionClassifications( aFunctor, rBegin, rEnd );
 
             return aFunctor.getCount();

Modified: openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx Tue Apr 29 19:25:03 2014
@@ -66,7 +66,7 @@ namespace slideshow
                 @param rWakeupEvent
                 Externally generated wakeup event, to set this
                 activity to sleep during inter-frame intervals. Must
-                come frome the outside, since wakeup event and this
+                come from the outside, since wakeup event and this
                 object have mutual references to each other.
 
                 @param rTimeouts

Modified: openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx Tue Apr 29 19:25:03 2014
@@ -52,7 +52,7 @@ namespace slideshow
             @param rWakeupEvent
             Externally generated wakeup event, to set this
             activity to sleep during inter-frame intervals. Must
-            come frome the outside, since wakeup event and this
+            come from the outside, since wakeup event and this
             object have mutual references to each other.
 
             @param rTimeouts

Modified: openoffice/trunk/main/slideshow/source/engine/slide/layer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/slide/layer.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/slide/layer.hxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/slide/layer.hxx Tue Apr 29 19:25:03 2014
@@ -52,13 +52,13 @@ namespace slideshow
 
         	Since slides have a notion of depth, i.e. shapes on it
         	have a certain order in which they lie upon each other,
-        	this layering must be modeled. A prime example for this
+        	this layering must be modelled. A prime example for this
         	necessity are animations of shapes lying behind other
         	shapes. Then, everything behind the animated shape will be
         	in a background layer, the shape itself will be in an
         	animation layer, and everything before it will be in a
-        	foreground layer (these layers are most preferrably
-        	modeled as XSprite objects internally).
+        	foreground layer (these layers are most preferably
+        	modelled as XSprite objects internally).
 
             @attention All methods of this class are only supposed to
             be called from the LayerManager. Normally, it shouldn't be

Modified: openoffice/trunk/main/slideshow/source/engine/slide/layermanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/slide/layermanager.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/slide/layermanager.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/slide/layermanager.cxx Tue Apr 29 19:25:03 2014
@@ -113,7 +113,7 @@ namespace slideshow
         {
             mbActive = true;
             maUpdateShapes.clear(); // update gets forced via area, or
-                                    // has happend outside already
+                                    // has happened outside already
 
             if( !bSlideBackgoundPainted )
             {

Modified: openoffice/trunk/main/slideshow/source/engine/slide/layermanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/slide/layermanager.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/slide/layermanager.hxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/slide/layermanager.hxx Tue Apr 29 19:25:03 2014
@@ -358,7 +358,7 @@ namespace slideshow
              */
             const basegfx::B2DRange  maPageBounds;
 
-            /// Number of shape sprites currenly active on this LayerManager
+            /// Number of shape sprites currently active on this LayerManager
             sal_Int32                mnActiveSprites;
 
             /// sal_True, if shapes might need to move to different layer

Modified: openoffice/trunk/main/slideshow/source/engine/transitions/clippingfunctor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/transitions/clippingfunctor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/transitions/clippingfunctor.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/transitions/clippingfunctor.cxx Tue Apr 29 19:25:03 2014
@@ -203,7 +203,7 @@ namespace slideshow 
                 else
                 {
 					// when not completely inside aBackgroundRange clipping is needed
-                    // substract aClipPoly from aBackgroundRange
+                    // subtract aClipPoly from aBackgroundRange
                     const basegfx::B2DPolyPolygon aBackgroundPolyPoly(basegfx::tools::createPolygonFromRect(aBackgroundRange));
                     aClipPoly = basegfx::tools::solvePolygonOperationDiff(aBackgroundPolyPoly, aClipPoly);
                 }

Modified: openoffice/trunk/main/slideshow/source/engine/wakeupevent.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/wakeupevent.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/wakeupevent.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/wakeupevent.cxx Tue Apr 29 19:25:03 2014
@@ -63,7 +63,7 @@ namespace slideshow
         
         bool WakeupEvent::isCharged() const
         {
-            // this event won't expire, we fire everytime we're
+            // this event won't expire, we fire every time we're
             // re-inserted into the event queue.
             return true;
         }

Modified: openoffice/trunk/main/slideshow/source/inc/animatedsprite.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/inc/animatedsprite.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/inc/animatedsprite.hxx (original)
+++ openoffice/trunk/main/slideshow/source/inc/animatedsprite.hxx Tue Apr 29 19:25:03 2014
@@ -103,7 +103,7 @@ namespace slideshow
             /** Query the content canvas for the current sprite.
 
             	Note that this method must be called
-            	<em>everytime</em> something is rendered to the
+            	<em>every time</em> something is rendered to the
             	sprite, because XCustomSprite does not guarantee the
             	validity of the canvas after a render operation.
 

Modified: openoffice/trunk/main/slideshow/source/inc/eventmultiplexer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/inc/eventmultiplexer.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/inc/eventmultiplexer.hxx (original)
+++ openoffice/trunk/main/slideshow/source/inc/eventmultiplexer.hxx Tue Apr 29 19:25:03 2014
@@ -56,7 +56,7 @@ struct EventMultiplexerImpl;
     are handled as well. Note that registered events which
     have a non-zero timeout (i.e. events that return non-zero
     from getActivationTime()) will not be fired immediately
-    after the user action occured, but only after the given
+    after the user action occurred, but only after the given
     timeout. Which is actually a feature.
 */
 class EventMultiplexer : private ::boost::noncopyable

Modified: openoffice/trunk/main/slideshow/source/inc/usereventqueue.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/inc/usereventqueue.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/inc/usereventqueue.hxx (original)
+++ openoffice/trunk/main/slideshow/source/inc/usereventqueue.hxx Tue Apr 29 19:25:03 2014
@@ -52,7 +52,7 @@ class MouseLeaveHandler;
     This class registeres at the EventMultiplexer and fires
     events registered for certain user actions. Note that all
     events will not be fired immediately after the user action
-    occured, but always added to the EventQueue (and fired the
+    occurred, but always added to the EventQueue (and fired the
     next time that queue is processed). Which is actually a
     feature.
     

Modified: openoffice/trunk/main/solenv/bin/build.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/build.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/build.pl (original)
+++ openoffice/trunk/main/solenv/bin/build.pl Tue Apr 29 19:25:03 2014
@@ -1049,7 +1049,7 @@ sub add_prerequisite_job {
 };
 
 #
-# procedure adds a job wich is dependent from all already registered jobs
+# procedure adds a job which is dependent from all already registered jobs
 #
 sub add_dependent_job {
     # $post_job is dependent from all jobs
@@ -1777,7 +1777,7 @@ sub handle_dead_children {
 
 sub give_second_chance {
     my $pid = shift;
-    # A malicious hack for misterious windows problems - try 2 times 
+    # A malicious hack for mysterious windows problems - try 2 times 
     # to run dmake in the same directory if errors occurs
     my $child_nick = $processes_hash{$pid};
     $running_children{$folders_hashes{$child_nick}}--;
@@ -3386,7 +3386,7 @@ sub run_server {
             };
         } else {
             if ($client_hash{result} eq "0") {
-#                print "$clients_jobs{$pid} succedded on $pid\n";
+#                print "$clients_jobs{$pid} succeeded on $pid\n";
             } else {
                 print "Error $client_hash{result}\n";
                 if (store_error($pid, $client_hash{result})) {

Modified: openoffice/trunk/main/solenv/bin/build_release.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/build_release.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/build_release.pl (original)
+++ openoffice/trunk/main/solenv/bin/build_release.pl Tue Apr 29 19:25:03 2014
@@ -1342,7 +1342,7 @@ sub ResolveTemplate ($$$$$)
     
     my $name = $template;
     
-    # Resolve %? template paramters.
+    # Resolve %? template parameters.
     $name =~ s/%V/$release_descriptor->{'version'}/g;
     $name =~ s/%W/$old_to_new_version_dash/g;
     $name =~ s/%w/$old_to_new_version_dots/g;

Modified: openoffice/trunk/main/solenv/bin/cws.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/cws.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/download_external_dependencies.pl (original)
+++ openoffice/trunk/main/solenv/bin/download_external_dependencies.pl Tue Apr 29 19:25:03 2014
@@ -587,7 +587,7 @@ sub DownloadFile ($$$)
 	close $out;
     }
     
-    # When download was successfull then check the checksum and rename the .part file
+    # When download was successful then check the checksum and rename the .part file
     # into the actual extension name.
     if ($success)
     {

Modified: openoffice/trunk/main/solenv/bin/make_download.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/make_download.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/make_download.pl (original)
+++ openoffice/trunk/main/solenv/bin/make_download.pl Tue Apr 29 19:25:03 2014
@@ -64,7 +64,7 @@ foreach my $infofilename ( @{$infofileli
 		installer::logger::print_message( "... WARNING: Signing only for Windows platforms active ...\n" );
 	}
 
-	# installer::logger::include_header_into_logfile("Reading include pathes");
+	# installer::logger::include_header_into_logfile("Reading include paths");
 	# installer::worker::collect_all_files_from_includepathes($followmeinfohash->{'includepatharray'});
 
 	if (( $installer::globals::iswindowsbuild ) && ( $installer::globals::dosign ))

Modified: openoffice/trunk/main/solenv/bin/make_installer.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/make_installer.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/make_installer.pl (original)
+++ openoffice/trunk/main/solenv/bin/make_installer.pl Tue Apr 29 19:25:03 2014
@@ -1470,7 +1470,7 @@ installer::ziplist::remove_ending_separa
 
 ##############################################
 # Collecting all files from all include
-# pathes in global hashes.
+# paths in global hashes.
 ##############################################
 
 installer::worker::collect_all_files_from_includepathes($includepatharrayref);
@@ -1954,7 +1954,7 @@ for (;1;last) 
 	# There are two ways for a directory to be included into the epm directory list:
 	# 1. Looking for all destination paths in the files array
 	# 2. Looking for directories with CREATE flag in the directory array
-	# Advantage: Many pathes are hidden in zip files, they are not defined in the setup script.
+	# Advantage: Many paths are hidden in zip files, they are not defined in the setup script.
 	# It will be possible, that in the setup script only those directoies have to be defined,
 	# that have a CREATE flag. All other directories are created, if they contain at least one file.
 

Modified: openoffice/trunk/main/solenv/bin/modules/Cws.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/Cws.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/Cws.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/Cws.pm Tue Apr 29 19:25:03 2014
@@ -1406,7 +1406,7 @@ sub set_integration_milestone_in_eis
     if ( !defined($milestone) ) {
         $milestone = Eis::to_string('');
     }
-    # $buildid must be transfered as string
+    # $buildid must be transferred as string
     if ( !defined($buildid) ) {
         $buildid = Eis::to_string('');
     }

Modified: openoffice/trunk/main/solenv/bin/modules/ExtensionsLst.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/ExtensionsLst.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/ExtensionsLst.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/ExtensionsLst.pm Tue Apr 29 19:25:03 2014
@@ -169,7 +169,7 @@ sub EvaluateTerm ($$)
             my $left_value = $ENV{$left};
             $left_value = "" if ! defined $left_value;
 
-            # We can check whether the condition is fullfilled right now.
+            # We can check whether the condition is fulfilled right now.
             $result = EvaluateOperator($left_value, $operator, $right);
         }
         elsif ($left eq "language")
@@ -506,7 +506,7 @@ sub Download (@)
         my $response = $agent->get($URL);
         close $out;
 
-        # When download was successfull then check the md5 checksum and rename the .part file
+        # When download was successful then check the md5 checksum and rename the .part file
         # into the actual extension name.
         if ($response->is_success())
         {

Modified: openoffice/trunk/main/solenv/bin/modules/installer/archivefiles.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/archivefiles.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/archivefiles.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/archivefiles.pm Tue Apr 29 19:25:03 2014
@@ -362,7 +362,7 @@ sub resolving_archive_flag
 						
 						if ( $set_executable_privileges )
 						{
-							# All pathes to executables are saved in the hash %executable_files_in_extensions
+							# All paths to executables are saved in the hash %executable_files_in_extensions
 							my $compare_path = $newfile{'sourcepath'};
 							$compare_path =~ s/\\/\//g;  # contains only slashes for comparison reasons
 							if ( exists($executable_files_in_extensions{$compare_path}) )

Modified: openoffice/trunk/main/solenv/bin/modules/installer/control.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/control.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/control.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/control.pm Tue Apr 29 19:25:03 2014
@@ -269,7 +269,7 @@ sub check_makecab_version
 }
 
 ######################################################################
-# Reading the environment variables for the pathes in ziplist.
+# Reading the environment variables for the paths in ziplist.
 # solarpath, solarenvpath, solarcommonpath, os, osdef, pmiscpath
 ######################################################################
 
@@ -378,7 +378,7 @@ sub check_logfile ()
         }
         else
         {
-            push(@output, "ERROR: The following errors occured in packaging process:\n");
+            push(@output, "ERROR: The following errors occurred in packaging process:\n");
         }
         push(@output, "\n");
 
@@ -557,7 +557,7 @@ sub check_updatepack
                         $installer::logger::Global->printf("Failed to create directory \n", $directory);
 						if ( defined $ENV{'BSCLIENT'} && ( uc $ENV{'BSCLIENT'} eq 'TRUE' ) )
                         {
-							installer::exiter::exit_program("ERROR: No write access to SHIPDRIVE allthough BSCLIENT is set.", "check_updatepack");
+							installer::exiter::exit_program("ERROR: No write access to SHIPDRIVE although BSCLIENT is set.", "check_updatepack");
 						}
 					}
 				}

Modified: openoffice/trunk/main/solenv/bin/modules/installer/converter.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/converter.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/converter.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/converter.pm Tue Apr 29 19:25:03 2014
@@ -273,7 +273,7 @@ sub copy_item_object
 }
 
 #################################################################
-# Windows pathes must not contain the following structure:
+# Windows paths must not contain the following structure:
 # c:\dirA\dirB\..\dirC
 # This has to be exchanged to 
 # c:\dirA\dirC

Modified: openoffice/trunk/main/solenv/bin/modules/installer/downloadsigner.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/downloadsigner.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/environment.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/environment.pm Tue Apr 29 19:25:03 2014
@@ -72,7 +72,7 @@ sub create_pathvariables
 }
 
 ##################################################
-# Replacing tilde in pathes, because of
+# Replacing tilde in paths, because of
 # problem with deep recursion (task 104830)
 ##################################################
 

Modified: openoffice/trunk/main/solenv/bin/modules/installer/epmfile.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/epmfile.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/epmfile.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/epmfile.pm Tue Apr 29 19:25:03 2014
@@ -55,7 +55,7 @@ sub read_packagemap
     $installer::logger::Lang->printf("\n");
     $installer::logger::Lang->printf("nCollected abbreviations and package names:\n");
 
-	# Can be a comma separated list. All files have to be found in include pathes
+	# Can be a comma separated list. All files have to be found in include paths
 	my $allpackagemapnames = installer::converter::convert_stringlist_into_hash(\$packagemapname, ",");
 	foreach my $onepackagemapname ( keys %{$allpackagemapnames} )
 	{

Modified: openoffice/trunk/main/solenv/bin/modules/installer/javainstaller.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/javainstaller.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/javainstaller.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/javainstaller.pm Tue Apr 29 19:25:03 2014
@@ -371,7 +371,7 @@ sub convert_licenstring
 #######################################################
 # Adding the license file into the java file
 # In the template java file there are two
-# occurences of INSTALLSDK_GUI_LICENSE
+# occurrences of INSTALLSDK_GUI_LICENSE
 # and INSTALLSDK_CONSOLE_LICENSE
 #######################################################
 

Modified: openoffice/trunk/main/solenv/bin/modules/installer/packagelist.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/packagelist.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/packagelist.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/packagelist.pm Tue Apr 29 19:25:03 2014
@@ -735,7 +735,7 @@ sub log_packages_content
 }
 
 #####################################################################
-# Creating assignments from modules to destination pathes.
+# Creating assignments from modules to destination paths.
 # This is required for logging in fileinfo file. Otherwise
 # the complete destination file would not be known in file list.
 # Saved in %installer::globals::moduledestination
@@ -761,7 +761,7 @@ sub create_module_destination_hash
 }
 
 #####################################################################
-# Adding the default pathes into the files collector for Unixes.
+# Adding the default paths into the files collector for Unixes.
 # This is necessary to know the complete destination path in
 # fileinfo log file.
 #####################################################################

Modified: openoffice/trunk/main/solenv/bin/modules/installer/packagepool.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/packagepool.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/parameter.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/parameter.pm Tue Apr 29 19:25:03 2014
@@ -202,7 +202,7 @@ sub control_fundamental_parameter
 
 ##########################################################
 # The path parameters can be relative or absolute.
-# This function creates absolute pathes.
+# This function creates absolute paths.
 ##########################################################
 
 sub make_path_absolute

Modified: openoffice/trunk/main/solenv/bin/modules/installer/patch/InstallationSet.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/patch/InstallationSet.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/patch/InstallationSet.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/patch/InstallationSet.pm Tue Apr 29 19:25:03 2014
@@ -475,7 +475,7 @@ sub Download ($$$)
         if ( ! defined $digest
             || $digest->hexdigest() eq $checksum_value)
         {
-            $installer::logger::Info->print("download was successfull\n");
+            $installer::logger::Info->print("download was successful\n");
             if ( ! rename($temporary_filename, $filename))
             {
                 installer::logger::PrintError("can not rename '%s' to '%s'\n", $temporary_filename, $filename);

Modified: openoffice/trunk/main/solenv/bin/modules/installer/scriptitems.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/scriptitems.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/scriptitems.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/scriptitems.pm Tue Apr 29 19:25:03 2014
@@ -1229,7 +1229,7 @@ sub get_Destination_Directory_For_Item_F
 }
 
 ##########################################################################
-# Searching a file in a list of pathes
+# Searching a file in a list of paths
 ##########################################################################
 
 sub get_sourcepath_from_filename_and_includepath_classic
@@ -1394,7 +1394,7 @@ sub determine_directory_language_depende
 }
 
 ##############################################################
-# Getting all source pathes for all files to be packed
+# Getting all source paths for all files to be packed
 # $item can be "Files" or "ScpActions"
 ##############################################################
 
@@ -2201,7 +2201,7 @@ sub quoting_illegal_filenames
 }
 
 ############################################################################
-# Removing multiple occurences of same module.
+# Removing multiple occurrences of same module.
 ############################################################################
 
 sub optimize_list
@@ -2581,7 +2581,7 @@ sub resolve_links_with_flag_relative
 	# Before this step is:
 	# destination=program/libsalhelperC52.so.3, this will be the name of the link
 	# destinationfile=program/libsalhelperC52.so.3, this will be the linked file or name
-	# If the flag RELATIVE is set, the pathes have to be analyzed. If the flag is not set
+	# If the flag RELATIVE is set, the paths have to be analyzed. If the flag is not set
 	# (this will not occur in the future?) destinationfile has to be an absolute path name
 
 	for ( my $i = 0; $i <= $#{$linksarrayref}; $i++ )

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/admin.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/admin.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/admin.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/admin.pm Tue Apr 29 19:25:03 2014
@@ -415,7 +415,7 @@ sub create_directory_structure
 	
 	foreach $dir (@startparents) { create_directory_tree($dir, \%fullpathhash, $targetdir, $dirhash); }
 
-	# Also adding the pathes of the startparents
+	# Also adding the paths of the startparents
 	foreach $dir (@startparents)
 	{
 		if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/directory.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/directory.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/directory.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/directory.pm Tue Apr 29 19:25:03 2014
@@ -126,7 +126,7 @@ sub make_short_dir_version ($)
 	$shortstring =~ s/^\s*\_//;
 
 	# Setting unique ID to each directory
-	# No counter allowed, process must be absolute reproducable due to patch creation process.
+	# No counter allowed, process must be absolute reproducible due to patch creation process.
 	
 	my $subid = installer::windows::msiglobal::calculate_id($longstring_save, 9); # taking only the first 9 digits
 	$shortstring = substr($shortstring, 0, $cutlength) . "_" . $subid;

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/feature.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/feature.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/feature.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/feature.pm Tue Apr 29 19:25:03 2014
@@ -435,7 +435,7 @@ sub add_missing_features ($)
 
     return $features if ! $installer::globals::is_release;
 
-    # Aquire the feature list of the source release.
+    # Acquire the feature list of the source release.
     my $source_feature_table = $installer::globals::source_msi->GetTable("Feature");
     my $feature_column_index = $source_feature_table->GetColumnIndex("Feature");
 

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/idtglobal.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/idtglobal.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/idtglobal.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/idtglobal.pm Tue Apr 29 19:25:03 2014
@@ -2130,7 +2130,7 @@ sub get_customaction_position
 
 ##########################################################################
 # Setting the position of CustomActions in sequence tables.
-# Replacing all occurences of "POSITIONTEMPLATE_"
+# Replacing all occurrences of "POSITIONTEMPLATE_"
 ##########################################################################
 
 sub set_positions_in_table
@@ -2140,7 +2140,7 @@ sub set_positions_in_table
 	$installer::logger::Lang->print("\n");
 	$installer::logger::Lang->printf("Setting positions in table \"%s\".\n", $tablename);
 
-	# Step 1: Resolving all occurences of "POSITIONTEMPLATE_end"
+	# Step 1: Resolving all occurrences of "POSITIONTEMPLATE_end"
 
 	my $lastposition = get_last_position_in_sequencetable($sequencetable);
 
@@ -2156,9 +2156,9 @@ sub set_positions_in_table
 		}
 	}
 	
-	# Step 2: Resolving all occurences of "POSITIONTEMPLATE_abc" or "POSITIONTEMPLATE_behind_abc"
+	# Step 2: Resolving all occurrences of "POSITIONTEMPLATE_abc" or "POSITIONTEMPLATE_behind_abc"
 	# where abc is the name of the reference Custom Action.
-	# This has to be done, until there is no more occurence of POSITIONTEMPLATE (success)
+	# This has to be done, until there is no more occurrence of POSITIONTEMPLATE (success)
 	# or there is no replacement in one circle (failure).
 	
 	my $template_exists = 0;
@@ -2213,7 +2213,7 @@ sub set_positions_in_table
 		}
 	} while (( $template_exists ) && ( $template_replaced ));
 
-	# An error occured, because templates still exist, but could not be replaced.
+	# An error occurred, because templates still exist, but could not be replaced.
 	# Reason:
 	# 1. Wrong name of CustomAction in scp2 (typo?)
 	# 2. Circular dependencies of CustomActions (A after B and B after A)

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/msiglobal.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/msiglobal.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/sign.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/sign.pm Tue Apr 29 19:25:03 2014
@@ -631,9 +631,9 @@ sub cabinet_cosistency_check
 				}		
 				else
 				{
-					$infoline = "ERROR: Problem occured calling diff.exe (File: $lastfile)\n";
+					$infoline = "ERROR: Problem occurred calling diff.exe (File: $lastfile)\n";
 					$installer::logger::Lang->print($infoline);								
-					installer::exiter::exit_program("ERROR: Problem occured calling diff.exe (File: $lastfile) !", "cabinet_cosistency_check");
+					installer::exiter::exit_program("ERROR: Problem occurred calling diff.exe (File: $lastfile) !", "cabinet_cosistency_check");
 				}
 			}
 		}		

Modified: openoffice/trunk/main/solenv/bin/modules/installer/worker.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/worker.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/xpdinstaller.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/xpdinstaller.pm Tue Apr 29 19:25:03 2014
@@ -441,8 +441,8 @@ sub get_forceintoupdate_value
 }
 
 ###################################################
-# Substituting all occurences of "<" by "&lt;" 
-# and all occurences of ">" by "&gt;"
+# Substituting all occurrences of "<" by "&lt;" 
+# and all occurrences of ">" by "&gt;"
 ###################################################
 
 sub replace_brackets_in_string
@@ -456,7 +456,7 @@ sub replace_brackets_in_string
 }
 
 ###################################################
-# Substituting all occurences of "\uUXYZ" by 
+# Substituting all occurrences of "\uUXYZ" by 
 # "&#xUXYZ;", because the use xml saxparser does
 # not know anything about this encoding. Therfore
 # the xml file can keep standard encoding "UTF-8"

Modified: openoffice/trunk/main/solenv/bin/modules/installer/ziplist.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/ziplist.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/osarch.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/osarch.pm Tue Apr 29 19:25:03 2014
@@ -23,7 +23,7 @@
 # ***********************************************************************
 # Description: 
 # Filename:    osarch.pm
-# Autor:       EG
+# Author:       EG
 # Date:        28.10.96
 # $Header: /zpool/svn/migration/cvs_rep_09_09_08/code/solenv/bin/modules/osarch.pm,v 1.3 2008-08-18 13:11:04 vg Exp $
 # Copyright:   STAR DIVISION

Modified: openoffice/trunk/main/solenv/bin/modules/packager/work.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/packager/work.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/packager/work.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/packager/work.pm Tue Apr 29 19:25:03 2014
@@ -289,7 +289,7 @@ sub do_broadcast
 	print "cmd_bcst -s 18 \@$tmpfile_name\n";
     unlink "$tmpfile_name";
 
-	if ( $returnvalue )	# an error occured
+	if ( $returnvalue )	# an error occurred
 	{
 		if (!($packager::globals::ignoreerrors)) { packager::exiter::exit_program("ERROR: Packing not successful!", "do_broadcast"); }
 	}

Modified: openoffice/trunk/main/solenv/bin/modules/par2script/parameter.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/par2script/parameter.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/par2script/parameter.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/par2script/parameter.pm Tue Apr 29 19:25:03 2014
@@ -47,7 +47,7 @@ sub usage
 --------------------------------------------------------------
 $par2script::globals::prog
 The following parameter are needed:
--i: include pathes, comma separated list
+-i: include paths, comma separated list
 -o: setup script file name
 -v: writing logfile.txt (optional)
 \@\@list: list of all par files
@@ -101,7 +101,7 @@ sub control_parameter
 	if ($par2script::globals::includepathlist eq "")
 	{
 		print "\n************************************************\n";
-		print "Error: Include pathes not set not set (-i)!";
+		print "Error: Include paths not set not set (-i)!";
 		print "\n************************************************\n";
 		usage();
 		exit(-1);

Modified: openoffice/trunk/main/solenv/bin/modules/par2script/work.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/par2script/work.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/pre2par/parameter.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/pre2par/parameter.pm Tue Apr 29 19:25:03 2014
@@ -128,7 +128,7 @@ sub control_parameter
 
 ##########################################################
 # The path parameters can be relative or absolute.
-# This function creates absolute pathes.
+# This function creates absolute paths.
 ##########################################################
 
 sub make_path_absolute

Modified: openoffice/trunk/main/solenv/bin/packimages.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/packimages.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/packimages.pl (original)
+++ openoffice/trunk/main/solenv/bin/packimages.pl Tue Apr 29 19:25:03 2014
@@ -45,7 +45,7 @@ my $global_path;             # path to g
 my $module_path;             # path to module images directory
 my $sort_file;               # path to file containing sorting data
 my @custom_path;             # path to custom images directory
-my @imagelist_path;          # pathes to directories containing the image lists
+my @imagelist_path;          # paths to directories containing the image lists
 my $verbose;                 # be verbose
 my $extra_verbose;           # be extra verbose
 my $do_rebuild = 0;          # is rebuilding zipfile required?

Modified: openoffice/trunk/main/solenv/bin/packregistry.xslt
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/packregistry.xslt?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/packregistry.xslt (original)
+++ openoffice/trunk/main/solenv/bin/packregistry.xslt Tue Apr 29 19:25:03 2014
@@ -39,7 +39,7 @@
       instead of the below for-each would only issue warnings, not errors, for
       non-existing or otherwise bad input files; it is important that the input
       filename list is already sorted in an order suitable for the configmgr
-      (e.g., xcs files preceeding xcu files).
+      (e.g., xcs files preceding xcu files).
 -->
       <xsl:for-each select="list/filename">
         <xsl:variable name="doc" select="document(concat($prefix, .))"/>

Modified: openoffice/trunk/main/solenv/bin/patch_tool.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/patch_tool.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/patch_tool.pl (original)
+++ openoffice/trunk/main/solenv/bin/patch_tool.pl Tue Apr 29 19:25:03 2014
@@ -1281,7 +1281,7 @@ sub Check ($$$$)
 {
     my ($source_msi, $target_msi, $variables, $product_name) = @_;
 
-    $installer::logger::Info->printf("checking if source and target releases are compatable\n");
+    $installer::logger::Info->printf("checking if source and target releases are compatible\n");
     $installer::logger::Info->increase_indentation();
 
     my $result = 1;

Modified: openoffice/trunk/main/solenv/bin/transform_description.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/transform_description.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/transform_description.pl (original)
+++ openoffice/trunk/main/solenv/bin/transform_description.pl Tue Apr 29 19:25:03 2014
@@ -126,7 +126,7 @@ sub explain
     print STDOUT "\n";
     print STDOUT "  The following transformations are done at the moment:\n";
     print STDOUT "  - duplicate all lines containing #LANG#, for ever token of \$WITH_LANG\n";
-    print STDOUT "    replacing every occurance of \$LANG with a token\n";
+    print STDOUT "    replacing every occurrence of \$LANG with a token\n";
     print STDOUT "\n";
     print STDOUT "  And yes, the functionality of this script should be\n";
     print STDOUT "  - moved to solenv/inc/tg_ext.mk\n";

Modified: openoffice/trunk/main/solenv/doc/gbuild/doxygen.cfg
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/doc/gbuild/doxygen.cfg?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/doc/gbuild/doxygen.cfg (original)
+++ openoffice/trunk/main/solenv/doc/gbuild/doxygen.cfg Tue Apr 29 19:25:03 2014
@@ -301,7 +301,7 @@ TYPEDEF_HIDES_STRUCT   = NO
 # causing a significant performance penality. 
 # If the system has enough physical memory increasing the cache will improve the 
 # performance by keeping more symbols in memory. Note that the value works on 
-# a logarithmic scale so increasing the size by one will rougly double the 
+# a logarithmic scale so increasing the size by one will roughly double the 
 # memory usage. The cache size is given by this formula: 
 # 2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0, 
 # corresponding to a cache size of 2^16 = 65536 symbols

Modified: openoffice/trunk/main/solenv/gbuild/LinkTarget.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/gbuild/LinkTarget.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/gbuild/LinkTarget.mk (original)
+++ openoffice/trunk/main/solenv/gbuild/LinkTarget.mk Tue Apr 29 19:25:03 2014
@@ -494,7 +494,7 @@ define gb_LinkTarget_add_external_libs
 
 # Make sure that all libraries are given as base names.
 ifneq (,$$(filter -l% lib% %.so %.lib, $(2)))
-$$(eval $$(call gb_Output_announce,ERROR: Please give only libary basenames to gb_LinkTarget_add_external_libs))
+$$(eval $$(call gb_Output_announce,ERROR: Please give only library basenames to gb_LinkTarget_add_external_libs))
 $$(eval $$(call gb_Output_announce,ERROR:    (no prefixes -l% or lib%, no suffixes %.so or %.lib)))
 $$(eval $$(call gb_Output_announce,ERROR:    libraries given: $(2)))
 $$(eval $$(call gb_Output_announce,ERROR:    offending: $$(filter -l% lib% %.so %.lib, $(2))))

Modified: openoffice/trunk/main/solenv/gbuild/gbuild.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/gbuild/gbuild.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/gbuild/gbuild.mk (original)
+++ openoffice/trunk/main/solenv/gbuild/gbuild.mk Tue Apr 29 19:25:03 2014
@@ -212,7 +212,7 @@ $(eval $(call gb_Deliver_init))
 # It is important to include them in the right order as that is
 # -- at least in part -- defining precedence. This is not an issue in the
 # WORKDIR as there are no nameing collisions there, but OUTDIR is a mess
-# and precedence is important there. This is also platform dependant.
+# and precedence is important there. This is also platform dependent.
 # For example:
 # $(OUTDIR)/bin/% for executables collides
 #	with $(OUTDIR)/bin/%.res for resources on unix

Modified: openoffice/trunk/main/solenv/inc/os2gcci.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/os2gcci.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/os2gcci.mk (original)
+++ openoffice/trunk/main/solenv/inc/os2gcci.mk Tue Apr 29 19:25:03 2014
@@ -44,7 +44,7 @@ EMXOMFOPT = -q
 #//YD SOLAR_JAVA=TRUE
 JAVAFLAGSDEBUG=-g
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/solenv/inc/settings.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/settings.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/settings.mk (original)
+++ openoffice/trunk/main/solenv/inc/settings.mk Tue Apr 29 19:25:03 2014
@@ -22,7 +22,7 @@
 
 MKFILENAME:=SETTINGS.MK
 
-# smaller/greater arithmetic's like ".IF 400<=200" are an OOo extention to
+# smaller/greater arithmetic's like ".IF 400<=200" are an OOo extension to
 # the initial dmake 4.1PL0 (unfortunately called 4.10) version and are
 # tested implicitly by the construction below.
 .IF $(MAKEVERSION:s/-cvs//:s/.//)<=410
@@ -602,7 +602,7 @@ LOCAL_COMMON_OUT:=$(subst,$(OUTPATH),$(C
 
 # disable for makefiles wrapping a gnumake module
 .IF "$(TARGET)"!="prj"
-# As this is not part of the initial startup makefile we define an infered
+# As this is not part of the initial startup makefile we define an inferred
 # target instead of using $(OUT)/inc/myworld.mk as target name.
 # (See iz62795)
 $(posix_PWD)/$(OUT)/inc/%world.mk :
@@ -1041,7 +1041,7 @@ MAXPROCESS!:=1
 .ENDIF			# "$(debug)"!=""
 
 # for multiprocess building in external modules
-# allow seperate handling
+# allow separate handling
 EXTMAXPROCESS*=$(MAXPROCESS)
 
 IDLC*=$(AUGMENT_LIBRARY_PATH) $(SOLARBINDIR)/idlc
@@ -1066,7 +1066,7 @@ JAVA*:=$(JAVAINTERPRETER)
 .EXPORT : JAVA JAVAI
 
 # Define SCPCOMP without wrapper because pre2par.pl chokes on DOS style
-# pathes. (See iz57443)
+# paths. (See iz57443)
 SCPCOMP=$(PERL) $(SOLARENV)/bin/pre2par.pl
 SCPLINK=$(PERL) $(SOLARENV)/bin/par2script.pl
 LZIP*=lzip

Modified: openoffice/trunk/main/solenv/inc/startup/Readme
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/startup/Readme?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/startup/Readme (original)
+++ openoffice/trunk/main/solenv/inc/startup/Readme Tue Apr 29 19:25:03 2014
@@ -1,6 +1,6 @@
 
 here are some hints about our use of the startup directory.
 
-the .INCLUDEDIRS line in startup.mk gives you the oportunity of switching
+the .INCLUDEDIRS line in startup.mk gives you the opportunity of switching
 to your own set of central makefiles.
 

Modified: openoffice/trunk/main/solenv/inc/target.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/target.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/target.mk (original)
+++ openoffice/trunk/main/solenv/inc/target.mk Tue Apr 29 19:25:03 2014
@@ -126,7 +126,7 @@ APP6RES=
 APP7RES=
 APP8RES=
 APP9RES=
-# unfortunatly there are some applications which don't VCL resources but have
+# unfortunately there are some applications which don't VCL resources but have
 # resources of their own
 .IF "$(APP1NOSVRES)" != ""
 APP1RES=$(APP1NOSVRES)

Modified: openoffice/trunk/main/solenv/inc/tg_compv.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/tg_compv.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/tg_compv.mk (original)
+++ openoffice/trunk/main/solenv/inc/tg_compv.mk Tue Apr 29 19:25:03 2014
@@ -62,7 +62,7 @@ CFLAGSNUMVERSION_CMD= -version |& cut -d
 CCVER:=$(shell @-$(CXX) $(CFLAGSVERSION_CMD))
 
 # and a computed integer for comparing
-# each point seperated token blown up to 4 digits
+# each point separated token blown up to 4 digits
 CCNUMVER:=$(shell @-$(CXX) $(CFLAGSNUMVERSION_CMD))
 
 .IF "$(COM)"=="MSC"

Modified: openoffice/trunk/main/solenv/inc/tg_javav.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/tg_javav.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/tg_javav.mk (original)
+++ openoffice/trunk/main/solenv/inc/tg_javav.mk Tue Apr 29 19:25:03 2014
@@ -38,7 +38,7 @@ JFLAGSNUMVERSION_CMD=-version $(PIPEERRO
 JAVAVER:=$(shell @-$(JAVA_HOME)/bin/java $(JFLAGSVERSION_CMD))
 
 # and a computed integer for comparing
-# each point seperated token blown up to 4 digits
+# each point separated token blown up to 4 digits
 JAVANUMVER:=$(shell @-$(JAVA_HOME)/bin/java $(JFLAGSNUMVERSION_CMD))
 
 .ELSE          # "$(SOLAR_JAVA)"!=""

Modified: openoffice/trunk/main/solenv/inc/unitools.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unitools.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unitools.mk (original)
+++ openoffice/trunk/main/solenv/inc/unitools.mk Tue Apr 29 19:25:03 2014
@@ -185,7 +185,7 @@ CONVERT*:=$(PERL) $(SOLARENV)/bin/leconv
 EXECTEST := $(PERL) -w $(SOLARENV)/bin/exectest.pl
 GCCINSTLIB:=$(PERL) -w $(SOLARENV)/bin/gccinstlib.pl
 
-# The dmake $(PWD) apparantly produces paths with symlinks resolved, while the
+# The dmake $(PWD) apparently produces paths with symlinks resolved, while the
 # bash pwd command by default produces paths with unresolved symlinks, so that
 # computing PATH_IN_MODULE in settings.mk would fail without the -P flag to the
 # bash pwd command:

Modified: openoffice/trunk/main/solenv/inc/unxbsdi.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unxbsdi.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unxbsdi.mk (original)
+++ openoffice/trunk/main/solenv/inc/unxbsdi.mk Tue Apr 29 19:25:03 2014
@@ -28,7 +28,7 @@ AFLAGS=
 SOLAR_JAVA=TRUE
 JAVAFLAGSDEBUG=-g
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/solenv/inc/unxbsdi2.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unxbsdi2.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unxbsdi2.mk (original)
+++ openoffice/trunk/main/solenv/inc/unxbsdi2.mk Tue Apr 29 19:25:03 2014
@@ -28,7 +28,7 @@ AFLAGS=
 SOLAR_JAVA=TRUE
 JAVAFLAGSDEBUG=-g
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/solenv/inc/unxbsds.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unxbsds.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unxbsds.mk (original)
+++ openoffice/trunk/main/solenv/inc/unxbsds.mk Tue Apr 29 19:25:03 2014
@@ -28,7 +28,7 @@ AFLAGS=-Wa,-Av8plusa,-K,PIC -x assembler
 SOLAR_JAVA=TRUE
 JAVAFLAGSDEBUG=-g
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/solenv/inc/unxfbsd.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unxfbsd.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unxfbsd.mk (original)
+++ openoffice/trunk/main/solenv/inc/unxfbsd.mk Tue Apr 29 19:25:03 2014
@@ -38,7 +38,7 @@ JAVAFLAGSDEBUG=-g
 .INCLUDE : unxfbsdx.mk
 .ENDIF
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/solenv/inc/unxlng.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/inc/unxlng.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/inc/unxlng.mk (original)
+++ openoffice/trunk/main/solenv/inc/unxlng.mk Tue Apr 29 19:25:03 2014
@@ -34,7 +34,7 @@ ARCH_FLAGS*=
 PICSWITCH*:=-fpic
 JAVAFLAGSDEBUG=-g
 
-# filter for supressing verbose messages from linker
+# filter for suppressing verbose messages from linker
 #not needed at the moment
 #LINKOUTPUT_FILTER=" |& $(SOLARENV)/bin/msg_filter"
 

Modified: openoffice/trunk/main/sot/qa/complex/olesimplestorage/Test01.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sot/qa/complex/olesimplestorage/Test01.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sot/qa/complex/olesimplestorage/Test01.java (original)
+++ openoffice/trunk/main/sot/qa/complex/olesimplestorage/Test01.java Tue Apr 29 19:25:03 2014
@@ -91,7 +91,7 @@ public class Test01 implements OLESimple
             
             //commit the storage and close it
             xOLESimpleStorage.commit ();
-            m_aTestHelper.Message ( "Storage commited." );
+            m_aTestHelper.Message ( "Storage committed." );
             xOLESimpleStorage.dispose ();
             for ( int i = 0; i < pStreamCnt; ++i )
             {

Modified: openoffice/trunk/main/sot/source/sdstor/stg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sot/source/sdstor/stg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sot/source/sdstor/stg.cxx (original)
+++ openoffice/trunk/main/sot/source/sdstor/stg.cxx Tue Apr 29 19:25:03 2014
@@ -749,7 +749,7 @@ sal_Bool Storage::CopyTo( const String& 
     if( pElem )
     {
 		/*
-		this lines are misterious !!! MM
+		this lines are mysterious !!! MM
         if( !pElem->IsContained( pDest->pEntry ) )
         {
             SetError( SVSTREAM_ACCESS_DENIED );
--- openoffice/trunk/main/solenv/bin/cws.pl (original)
+++ openoffice/trunk/main/solenv/bin/cws.pl Tue Apr 29 19:25:03 2014
@@ -126,7 +126,7 @@ sub parse_command_line
     my $command = shift @ARGV;
 
     if (!exists $valid_commands_hash{$command}) {
-        print_error("Unkown command: '$command'\n");
+        print_error("Unknown command: '$command'\n");
         usage();
         exit(1);
     }
@@ -144,7 +144,7 @@ sub parse_command_line
         $command = 'task';
     }
 
     # An unkown option might be accompanied with a valid command.
     # Show the command specific help
     if ( !$success ) {
         do_help([$command])
@@ -607,7 +607,7 @@ sub query_integratedinto
     if ( is_valid_cws($cws) ) {
         my $milestone = $cws->get_milestone_integrated();
         print_message("Integrated into:");
-        print defined($milestone) ? "$milestone\n" : "unkown\n";
+        print defined($milestone) ? "$milestone\n" : "unknown\n";
     }
     return;
 } 
@@ -1405,7 +1405,7 @@ sub do_help
     elsif ($arg eq 'create') {
         print STDERR "create: Create a new child workspace\n";
         print STDERR "usage: create [-m milestone] <master workspace> <child workspace>\n";
-        print STDERR "\t-m milestone:          Milestone to base the child workspace on. If ommitted the\n";
+        print STDERR "\t-m milestone:          Milestone to base the child workspace on. If omitted the\n";
         print STDERR "\t                       last published milestone will be used.\n";
         print STDERR "\t--milestone milestone: Same as -m milestone.\n";
     }
@@ -2012,7 +2012,7 @@ sub hg_clone
         print STDERR "CWS-DEBUG: ... hg clone: '$source -> $dest', options: '$options'\n";
     }
 
-    # The to be cloned revision might not yet be avaliable. In this case clone
+    # The to be cloned revision might not yet be available. In this case clone
     # the available tip.
     my @result = execute_hg_command(0, 'clone', $options, $source, $dest);
     if ( defined($result[0]) && $result[0] =~ /abort: unknown revision/ ) {
@@ -144,7 +144,7 @@ sub parse_command_line
     }
 
-    # An unkown option might be accompanied with a valid command.
+    # An unknown option might be accompanied with a valid command.
     # Show the command specific help
     if ( !$success ) {

Modified: openoffice/trunk/main/solenv/bin/download_external_dependencies.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/download_external_dependencies.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/downloadsigner.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/downloadsigner.pm Tue Apr 29 19:25:03 2014
@@ -200,7 +200,7 @@ sub set_temp_path
 }
 
 #############################################
 # Setting output pathes to temp directory
 # This are the:
 # unpackpath and the loggingdir
 #############################################
@@ -214,7 +214,7 @@ sub set_output_pathes_to_temp
 }
 
 #############################################
 # Setting the minor into the pathes. This is
 # required, if the original installation set
 # was created without minor
 # Value is always saved in 
@@ -240,20 +240,20 @@ sub set_minor_into_pathes
 		return;
 	}
 
-	# Affected pathes:
+	# Affected paths:
 	# $contenthash{'installlogdir'}
 	# $contenthash{'includepatharray'}
 	# $installer::globals::unpackpath
 	# $installer::globals::idttemplatepath
 	# $installer::globals::idtlanguagepath
 
-	installer::logger::include_header_into_logfile("Changing saved pathes to add the minor");
-    $installer::logger::Lang->print("Old pathes:\n");
+	installer::logger::include_header_into_logfile("Changing saved paths to add the minor");
+    $installer::logger::Lang->print("Old paths:\n");
     $installer::logger::Lang->printf("\$followmeinfohash->{'installlogdir'}: %s\n", $followmeinfohash->{'installlogdir'});
     $installer::logger::Lang->printf("\$installer::globals::unpackpath: %s\n", $installer::globals::unpackpath);
     $installer::logger::Lang->printf("\$installer::globals::idttemplatepath: %s\n", $installer::globals::idttemplatepath);
     $installer::logger::Lang->printf("\$installer::globals::idtlanguagepath: %s\n", $installer::globals::idtlanguagepath);
-    $installer::logger::Lang->printf("Include pathes:\n");
+    $installer::logger::Lang->printf("Include paths:\n");
 	foreach my $path ( @{$followmeinfohash->{'includepatharray'}} )
     {
         $installer::logger::Lang->print($path);
@@ -301,12 +301,12 @@ sub set_minor_into_pathes
 	foreach my $path ( @{$followmeinfohash->{'includepatharray'}} ) { if ( $path =~ /\Q$srcpath\E/ ) { $path =~ s/\Q$srcpath\E/$newsrcpath/; } }
 
     $installer::logger::Lang->print("\n");
-    $installer::logger::Lang->print("New pathes:\n");
+    $installer::logger::Lang->print("New paths:\n");
     $installer::logger::Lang->printf("\$followmeinfohash->{'installlogdir'}: %s\n", $followmeinfohash->{'installlogdir'});
     $installer::logger::Lang->printf("\$installer::globals::unpackpath: %s\n", $installer::globals::unpackpath);
     $installer::logger::Lang->printf("\$installer::globals::idttemplatepath: %s\n", $installer::globals::idttemplatepath);
     $installer::logger::Lang->printf("\$installer::globals::idtlanguagepath: %s\n", $installer::globals::idtlanguagepath);
-    $installer::logger::Lang->printf("Include pathes:\n");
+    $installer::logger::Lang->printf("Include paths:\n");
 	foreach my $path ( @{$followmeinfohash->{'includepatharray'}} )
     {
         $installer::logger::Lang->print($path);
@@ -200,7 +200,7 @@ sub set_temp_path
 
 #############################################
-# Setting output pathes to temp directory
+# Setting output paths to temp directory
 # This are the:
 # unpackpath and the loggingdir
@@ -214,7 +214,7 @@ sub set_output_pathes_to_temp
 
 #############################################
-# Setting the minor into the pathes. This is
+# Setting the minor into the paths. This is
 # required, if the original installation set
 # was created without minor

Modified: openoffice/trunk/main/solenv/bin/modules/installer/environment.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/environment.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/packagepool.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/packagepool.pm Tue Apr 29 19:25:03 2014
@@ -90,7 +90,7 @@ sub compare_epm_content
 	for ( my $i = 0; $i <= $#{$newcontent}; $i++ )
 	{
 		if ( ${$newcontent}[$i] =~ /^\s*$/ ) { next; } # Removing empty lines from $newcontent. Empty lines are also not included into pcf file, from where $oldcontent was read.
-		if ( ${$newcontent}[$i] =~ /^\s*f\s+/ ) { next; } # Ignoring files, they can contain temporary pathes
+		if ( ${$newcontent}[$i] =~ /^\s*f\s+/ ) { next; } # Ignoring files, they can contain temporary paths
 		if (( ${$newcontent}[$i] =~ /^\s*%readme\s+/ ) || ( ${$newcontent}[$i] =~ /^\s*%license\s+/ )) { next; } # ignoring license and readme (language specific!)
 		my $oneline = ${$newcontent}[$i];
 		$oneline =~ s/\s*$//; # Removing line ends. Also not included in old epm file, that is read from pcf file.
@@ -308,7 +308,7 @@ sub create_pcfcontent_file
 	for ( my $i = 0; $i <= $#{$epmfilecontent}; $i++ )
 	{
 		if ( ${$epmfilecontent}[$i] =~ /^\s*$/ ) { next; } # avoiding empty lines
-		if ( ${$epmfilecontent}[$i] =~ /^\s*f\s+/ ) { next; } # ignoring files, because they can contain temporary pathes
+		if ( ${$epmfilecontent}[$i] =~ /^\s*f\s+/ ) { next; } # ignoring files, because they can contain temporary paths
 		if (( ${$epmfilecontent}[$i] =~ /^\s*%readme\s+/ ) || ( ${$epmfilecontent}[$i] =~ /^\s*%license\s+/ )) { next; } # ignoring license and readme (language specific!)
 		$oneline = "EPM:\t${$epmfilecontent}[$i]";
 		push(@content, $oneline);
@@ -775,7 +775,7 @@ sub package_is_up_to_date
 		log_pool_info(0);
 		
 		# removing new package from installation set
-		if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occured with pooling
+		if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occurred with pooling
 		
 		$package_is_up_to_date = 4;	# repeat this package
 		return $package_is_up_to_date;
@@ -788,7 +788,7 @@ sub package_is_up_to_date
 		log_pool_info(1);
 
 		# removing new package from installation set
-		if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occured with pooling
+		if ( $newpackagepath ne "" ) { remove_package_from_installset($newpackagepath); } 	# A file was copied and a problem occurred with pooling
 
 		$package_is_up_to_date = 4;	# repeat this package
 		return $package_is_up_to_date;
@@ -946,7 +946,7 @@ sub put_content_into_pool
 	}
 	
 	# Before the new package is renamed in the pool, it has to be checked, if this process still has the lock for this package.
 	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
 	if ( ! -f $installer::globals::poollockfilename )
 	{
 		unlink $uniquedestination;  # removing file from pool
@@ -968,7 +968,7 @@ sub put_content_into_pool
 	$installer::logger::Lang->print($infoline);
 
 	# Before the lock file in the pool can be removed, it has to be checked, if this process is still the owner of this lock file.
 	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
 	if ( ! -f $installer::globals::poollockfilename )
 	{
 		log_pool_info(0);
@@ -1015,7 +1015,7 @@ sub copy_package_from_pool
 		$destinationfile =~ s/.tar\s*$//;
 	}
 	
-	# Keeping the content of @installer::globals::installsetcontent up to date (with full pathes):
+	# Keeping the content of @installer::globals::installsetcontent up to date (with full paths):
 	push(@installer::globals::installsetcontent, $destinationfile);
 	
 	return $destinationfile;
@@ -946,7 +946,7 @@ sub put_content_into_pool
 	
 	# Before the new package is renamed in the pool, it has to be checked, if this process still has the lock for this package.
-	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
+	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occurred.
 	if ( ! -f $installer::globals::poollockfilename )
 	{
@@ -968,7 +968,7 @@ sub put_content_into_pool
 
 	# Before the lock file in the pool can be removed, it has to be checked, if this process is still the owner of this lock file.
-	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occured.
+	# Check, if lock file still exists and if this process is the owner. Otherwise a pool error occurred.
 	if ( ! -f $installer::globals::poollockfilename )
 	{

Modified: openoffice/trunk/main/solenv/bin/modules/installer/parameter.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/parameter.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/windows/msiglobal.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/windows/msiglobal.pm Tue Apr 29 19:25:03 2014
@@ -109,7 +109,7 @@ sub check_ddf_file
 
 ##########################################################################
 # Lines in ddf files must not be longer than 256 characters.
-# Therefore it can be useful to use relative pathes. Then it is
+# Therefore it can be useful to use relative paths. Then it is
 # necessary to change into temp directory before calling 
 # makecab.exe.
 ##########################################################################
@@ -183,7 +183,7 @@ sub generate_cab_file_list ($$$$)
             $sourcepath = $onefile->{'cyg_sourcepath'};
         }
 
-        # to avoid lines with more than 256 characters, it can be useful to use relative pathes
+        # to avoid lines with more than 256 characters, it can be useful to use relative paths
         if ($allvariables->{'RELATIVE_PATHES_IN_DDF'})
         {
             $sourcepath = make_relative_ddf_path($sourcepath);
@@ -581,9 +581,9 @@ sub create_transforms
 		my $infoline = "Systemcall: $systemcall\n";
 		$installer::logger::Lang->print($infoline);
 		
 		# Problem: msitran.exe in version 4.0 always returns "1", even if no failure occured.
 		# Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
 		# exists and if it is larger than 0 bytes. If this is true, then no error occured.
 		# File Version of msitran.exe: 4.0.6000.16384 has checksum: "b66190a70145a57773ec769e16777b29".
 		# Same for msitran.exe from wntmsci12: "aa25d3445b94ffde8ef0c1efb77a56b8"
 		
@@ -628,13 +628,13 @@ sub create_transforms
 					}
 					else
 					{
-						$infoline = "Filesize indicates that an error occured.\n";
+						$infoline = "Filesize indicates that an error occurred.\n";
 						$installer::logger::Lang->print($infoline);
 					}
 				}
 				else
 				{
-					$infoline = "File $transformfile does not exist -> An error occured.\n";
+					$infoline = "File $transformfile does not exist -> An error occurred.\n";
 					$installer::logger::Lang->print($infoline);					
 				}
 			}
@@ -1289,7 +1289,7 @@ sub prepare_64bit_database
 			}
 		}
 		
-		# 2. Replacing all occurences of "VersionNT" by "VersionNT64"
+		# 2. Replacing all occurrences of "VersionNT" by "VersionNT64"
 		
 		my @versionnt_files = ("Componen.idt", "InstallE.idt", "InstallU.idt", "LaunchCo.idt");
 		
@@ -1413,7 +1413,7 @@ sub execute_packaging
 	$infoline = "chdir: $to \n";
 	$installer::logger::Lang->print($infoline);	
 
-	# if the ddf file contains relative pathes, it is necessary to change into the temp directory
+	# if the ddf file contains relative paths, it is necessary to change into the temp directory
 	if ( $allvariables->{'RELATIVE_PATHES_IN_DDF'} )
 	{
 		$to = $installer::globals::temppath;
@@ -581,9 +581,9 @@ sub create_transforms
 		$installer::logger::Lang->print($infoline);
 		
-		# Problem: msitran.exe in version 4.0 always returns "1", even if no failure occured.
+		# Problem: msitran.exe in version 4.0 always returns "1", even if no failure occurred.
 		# Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
@@ -581,9 +581,9 @@ sub create_transforms
 		# Therefore it has to be checked, if this is version 4.0. If yes, if the mst file
-		# exists and if it is larger than 0 bytes. If this is true, then no error occured.
+		# exists and if it is larger than 0 bytes. If this is true, then no error occurred.
 		# File Version of msitran.exe: 4.0.6000.16384 has checksum: "b66190a70145a57773ec769e16777b29".
 		# Same for msitran.exe from wntmsci12: "aa25d3445b94ffde8ef0c1efb77a56b8"

Modified: openoffice/trunk/main/solenv/bin/modules/installer/windows/sign.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/windows/sign.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/worker.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/worker.pm Tue Apr 29 19:25:03 2014
@@ -492,7 +492,7 @@ sub analyze_and_save_logfile
 	
 	if ( $installer::globals::creating_windows_installer_patch ) { $installer::globals::creating_windows_installer_patch = 0; }
 	
-	# Exiting the packaging process, if an error occured.
+	# Exiting the packaging process, if an error occurred.
 	# This is important, to get an error code "-1", if an error was found in the log file,
 	# that did not break the packaging process
 	
@@ -607,7 +607,7 @@ sub copy_hash_from_references
 
 ###########################################################
 # Setting one language in the language independent
 # array of include pathes with $(LANG)
 ###########################################################
 
 sub get_language_specific_include_pathes
@@ -2354,7 +2354,7 @@ sub add_variables_from_inc_to_hashref
 }
 
 ##############################################
 # Collecting all files from include pathes
 ##############################################
 
 sub collect_all_files_from_includepathes
@@ -2362,7 +2362,7 @@ sub collect_all_files_from_includepathes
 	my ($patharrayref) = @_;
 
 	installer::logger::globallog("Reading all directories: Start");
-	$installer::logger::Info->print( "... reading include pathes ...\n" );
+	$installer::logger::Info->print( "... reading include paths ...\n" );
 	# empty the global 
 	
 	@installer::globals::allincludepathes =();
@@ -2668,7 +2668,7 @@ sub set_time_stamp
 }
 
 ############################################################
 # Generating pathes for cygwin (first version)
 # This function has problems with cygwin, if $tmpfilename
 # contains many thousand files (OpenOffice SDK).
 ############################################################
@@ -2695,7 +2695,7 @@ sub generate_cygwin_pathes_old
 }
 
 #################################################
 # Generating pathes for cygwin (second version)
 # This function generates smaller files for
 #################################################
 
@@ -2703,12 +2703,12 @@ sub generate_cygwin_pathes
 {
 	my ($filesref) = @_;
 
-	$installer::logger::Lang->add_timestamp("Starting generating cygwin pathes");
+	$installer::logger::Lang->add_timestamp("Starting generating cygwin paths");
 	
-	my $infoline = "Generating cygwin pathes (generate_cygwin_pathes)\n";
+	my $infoline = "Generating cygwin paths (generate_cygwin_pathes)\n";
 	$installer::logger::Lang->print($infoline);	
 	
-	my $max = 5000;  # number of pathes in one file
+	my $max = 5000;  # number of paths in one file
 	
 	my @pathcollector = ();
 	my $startnumber = 0;
@@ -2726,7 +2726,7 @@ sub generate_cygwin_pathes
 			my $temppath = $installer::globals::temppath;
 			$temppath =~ s/\Q$installer::globals::separator\E\s*$//;
 			$tmpfilename = $temppath . $installer::globals::separator . $tmpfilename;
-			$infoline = "Creating temporary file for cygwin conversion: $tmpfilename (contains $counter pathes)\n";
+			$infoline = "Creating temporary file for cygwin conversion: $tmpfilename (contains $counter paths)\n";
 			$installer::logger::Lang->print($infoline);	
 			if ( -f $tmpfilename ) { unlink $tmpfilename; }
 
@@ -2751,9 +2751,9 @@ sub generate_cygwin_pathes
 			}
 			else
 			{
-                $installer::logger::Lang->print("ERROR: Failed to convert to cygwin pathes!\n");
+                $installer::logger::Lang->print("ERROR: Failed to convert to cygwin paths!\n");
                 installer::exiter::exit_program(
-                    "ERROR: Failed to convert to cygwin pathes!",
+                    "ERROR: Failed to convert to cygwin paths!",
                     "generate_cygwin_pathes");
 			}
 
@@ -2782,7 +2782,7 @@ sub generate_cygwin_pathes
 		}
 	}
 
-	$installer::logger::Lang->add_timestamp("Ending generating cygwin pathes");
+	$installer::logger::Lang->add_timestamp("Ending generating cygwin paths");
 }
 
 ##############################################
@@ -607,7 +607,7 @@ sub copy_hash_from_references
 ###########################################################
 # Setting one language in the language independent
-# array of include pathes with $(LANG)
+# array of include paths with $(LANG)
 ###########################################################
 
@@ -2354,7 +2354,7 @@ sub add_variables_from_inc_to_hashref
 
 ##############################################
-# Collecting all files from include pathes
+# Collecting all files from include paths
 ##############################################
 
@@ -2668,7 +2668,7 @@ sub set_time_stamp
 
 ############################################################
-# Generating pathes for cygwin (first version)
+# Generating paths for cygwin (first version)
 # This function has problems with cygwin, if $tmpfilename
 # contains many thousand files (OpenOffice SDK).
@@ -2695,7 +2695,7 @@ sub generate_cygwin_pathes_old
 
 #################################################
-# Generating pathes for cygwin (second version)
+# Generating paths for cygwin (second version)
 # This function generates smaller files for
 #################################################

Modified: openoffice/trunk/main/solenv/bin/modules/installer/xpdinstaller.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/xpdinstaller.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/ziplist.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/ziplist.pm Tue Apr 29 19:25:03 2014
@@ -639,7 +639,7 @@ sub replace_packagetype_in_pathes
 }
 
 ####################################################
 # Removing ending separators in pathes
 ####################################################
 
 sub remove_ending_separator
@@ -667,7 +667,7 @@ sub replace_languages_in_pathes
 {
 	my ( $patharrayref, $languagesref ) = @_;
 
-	installer::logger::include_header_into_logfile("Replacing languages in include pathes:");
+	installer::logger::include_header_into_logfile("Replacing languages in include paths:");
 	
 	my @patharray = ();
 	my $infoline = "";
@@ -691,7 +691,7 @@ sub replace_languages_in_pathes
 				
 				installer::remover::remove_leading_and_ending_whitespaces(\$newline);
 
 				# Is it necessary to refresh the global array, containing all files of all include pathes?
 				if ( -d $newdir )
 				{
 					# Checking if $newdir is empty
@@ -731,7 +731,7 @@ sub list_all_files_from_include_path
 {
 	my ( $patharrayref) = @_;
 	
-	installer::logger::include_header_into_logfile("Include pathes:");
+	installer::logger::include_header_into_logfile("Include paths:");
 	
 	for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
 	{
@@ -790,7 +790,7 @@ sub set_default_productversion_if_requir
 }
 
 ####################################################
 # Removing .. in pathes
 ####################################################
 
 sub simplify_path
@@ -813,7 +813,7 @@ sub simplify_path
 }
 
 ####################################################
 # Removing ending separators in pathes
 ####################################################
 
 sub resolve_relative_pathes
@@ -639,7 +639,7 @@ sub replace_packagetype_in_pathes
 
 ####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
 ####################################################
 
@@ -691,7 +691,7 @@ sub replace_languages_in_pathes
 				installer::remover::remove_leading_and_ending_whitespaces(\$newline);
 
-				# Is it necessary to refresh the global array, containing all files of all include pathes?
+				# Is it necessary to refresh the global array, containing all files of all include paths?
 				if ( -d $newdir )
 				{
@@ -790,7 +790,7 @@ sub set_default_productversion_if_requir
 
 ####################################################
-# Removing .. in pathes
+# Removing .. in paths
 ####################################################
 
@@ -813,7 +813,7 @@ sub simplify_path
 
 ####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
 ####################################################
 

Modified: openoffice/trunk/main/solenv/bin/modules/osarch.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/osarch.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/par2script/work.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/par2script/work.pm Tue Apr 29 19:25:03 2014
@@ -62,14 +62,14 @@ sub analyze_comma_separated_list
 }
 
 ############################################
 # setting list of include pathes
 ############################################
 
 sub setincludes
 {
 	my ($list) = @_;
 	
 	# input is the comma separated list of include pathes
 	
 	my $includes = analyze_comma_separated_list($list);
 
@@ -127,7 +127,7 @@ sub make_complete_pathes_for_parfiles
 
 		if ( ! $foundparfile )
 		{
-			die "ERROR: Could not find parfile ${$parfiles}[$i] in includes pathes: $par2script::globals::includepathlist !\n"; 	
+			die "ERROR: Could not find parfile ${$parfiles}[$i] in includes paths: $par2script::globals::includepathlist !\n"; 	
 		}	
 	}
 }
@@ -62,14 +62,14 @@ sub analyze_comma_separated_list
 
 ############################################
-# setting list of include pathes
+# setting list of include paths
 ############################################
 
@@ -62,14 +62,14 @@ sub analyze_comma_separated_list
 	my ($list) = @_;
 	
-	# input is the comma separated list of include pathes
+	# input is the comma separated list of include paths
 	
 	my $includes = analyze_comma_separated_list($list);

Modified: openoffice/trunk/main/solenv/bin/modules/pre2par/parameter.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/pre2par/parameter.pm?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================